@@ -5,47 +5,46 @@
 ( cd usr/share/locale ; rm -rf ja_JP )
 ( cd usr/share/locale ; ln -sf ja_JP.eucJP ja_JP )
 ( cd lib ; rm -rf ld-linux.so.2 )
-( cd lib ; ln -sf ld-2.10.1.so ld-linux.so.2 )
+( cd lib ; ln -sf ld-2.10.2.so ld-linux.so.2 )
 ( cd lib ; rm -rf libc.so.6 )
-( cd lib ; ln -sf libc-2.10.1.so libc.so.6 )
+( cd lib ; ln -sf libc-2.10.2.so libc.so.6 )
 ( cd lib ; rm -rf libBrokenLocale.so.1 )
-( cd lib ; ln -sf libBrokenLocale-2.10.1.so libBrokenLocale.so.1 )
+( cd lib ; ln -sf libBrokenLocale-2.10.2.so libBrokenLocale.so.1 )
 ( cd lib ; rm -rf libm.so.6 )
-( cd lib ; ln -sf libm-2.10.1.so libm.so.6 )
+( cd lib ; ln -sf libm-2.10.2.so libm.so.6 )
 ( cd lib ; rm -rf libdl.so.2 )
-( cd lib ; ln -sf libdl-2.10.1.so libdl.so.2 )
+( cd lib ; ln -sf libdl-2.10.2.so libdl.so.2 )
 ( cd lib ; rm -rf libcrypt.so.1 )
-( cd lib ; ln -sf libcrypt-2.10.1.so libcrypt.so.1 )
+( cd lib ; ln -sf libcrypt-2.10.2.so libcrypt.so.1 )
 ( cd lib ; rm -rf libpthread.so.0 )
-( cd lib ; ln -sf libpthread-2.10.1.so libpthread.so.0 )
+( cd lib ; ln -sf libpthread-2.10.2.so libpthread.so.0 )
 ( cd lib ; rm -rf libresolv.so.2 )
-( cd lib ; ln -sf libresolv-2.10.1.so libresolv.so.2 )
+( cd lib ; ln -sf libresolv-2.10.2.so libresolv.so.2 )
 ( cd lib ; rm -rf libnss_dns.so.2 )
-( cd lib ; ln -sf libnss_dns-2.10.1.so libnss_dns.so.2 )
+( cd lib ; ln -sf libnss_dns-2.10.2.so libnss_dns.so.2 )
 ( cd lib ; rm -rf libanl.so.1 )
-( cd lib ; ln -sf libanl-2.10.1.so libanl.so.1 )
+( cd lib ; ln -sf libanl-2.10.2.so libanl.so.1 )
 ( cd lib ; rm -rf libnss_files.so.2 )
-( cd lib ; ln -sf libnss_files-2.10.1.so libnss_files.so.2 )
+( cd lib ; ln -sf libnss_files-2.10.2.so libnss_files.so.2 )
 ( cd lib ; rm -rf librt.so.1 )
-( cd lib ; ln -sf librt-2.10.1.so librt.so.1 )
+( cd lib ; ln -sf librt-2.10.2.so librt.so.1 )
 ( cd lib ; rm -rf libcidn.so.1 )
-( cd lib ; ln -sf libcidn-2.10.1.so libcidn.so.1 )
+( cd lib ; ln -sf libcidn-2.10.2.so libcidn.so.1 )
 ( cd lib ; rm -rf libthread_db.so.1 )
 ( cd lib ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
 ( cd lib ; rm -rf libnss_hesiod.so.2 )
-( cd lib ; ln -sf libnss_hesiod-2.10.1.so libnss_hesiod.so.2 )
+( cd lib ; ln -sf libnss_hesiod-2.10.2.so libnss_hesiod.so.2 )
 ( cd lib ; rm -rf libnsl.so.1 )
-( cd lib ; ln -sf libnsl-2.10.1.so libnsl.so.1 )
+( cd lib ; ln -sf libnsl-2.10.2.so libnsl.so.1 )
 ( cd lib ; rm -rf libnss_nis.so.2 )
-( cd lib ; ln -sf libnss_nis-2.10.1.so libnss_nis.so.2 )
+( cd lib ; ln -sf libnss_nis-2.10.2.so libnss_nis.so.2 )
 ( cd lib ; rm -rf libnss_nisplus.so.2 )
-( cd lib ; ln -sf libnss_nisplus-2.10.1.so libnss_nisplus.so.2 )
+( cd lib ; ln -sf libnss_nisplus-2.10.2.so libnss_nisplus.so.2 )
 ( cd lib ; rm -rf libnss_compat.so.2 )
-( cd lib ; ln -sf libnss_compat-2.10.1.so libnss_compat.so.2 )
+( cd lib ; ln -sf libnss_compat-2.10.2.so libnss_compat.so.2 )
 ( cd lib ; rm -rf libutil.so.1 )
-( cd lib ; ln -sf libutil-2.10.1.so libutil.so.1 )
-#%% begin initialize glibc-2.10.1-i586-P1
-echo "glibc-2.10.1 ν"
+( cd lib ; ln -sf libutil-2.10.2.so libutil.so.1 )
+#%% begin initialize glibc-2.10.2-i586-P1
 # ¸ ld.so.conf ̵п ld.so.conf.new  ld.so.conf Ȥ뤬
 # ФΤޤޤˤƤ
 if [ ! -f /etc/ld.so.conf ]; then
@@ -60,16 +59,14 @@ ldconfig
 if [ ! -f /etc/nsswitch.conf ]; then
   mv /etc/nsswitch.conf.new /etc/nsswitch.conf
 else
-  rm nsswitch.conf.new
+  rm /etc/nsswitch.conf.new
 fi
 
-echo "timezone "
 # ¸localtimeФΤޤޡ̵JSTǺ
 if [ ! -e /etc/localtime ]; then
    TIMEZONE="Japan"
    ( cd /usr/share/zoneinfo ; ln -sf posix/$TIMEZONE localtime )
-   ( cd /etc ; cp ../usr/share/zoneinfo/localtime localtime )
+   ( cd /etc ; cp cp ../usr/share/zoneinfo/localtime localtime )
 fi
 
-echo "glibc-2.10.1 νλ"
 #%% end
